@@ -162,7 +162,7 @@ class TextModerationRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Content: 该字段表示待检测对象的文本内容，长度不能超过10000（按unicode编码计算）
+        :param Content: 该字段表示待检测对象的文本内容，文本需要按utf-8格式编码，长度不能超过10000（按unicode编码计算），并进行 Base64加密
         :type Content: str
         :param BizType: 该字段表示策略的具体编号，用于接口调度，在内容安全控制台中可配置。若不传入Biztype参数（留空），则代表采用默认的识别策略；传入则会在审核时根据业务场景采取不同的审核策略。<br>备注：Biztype仅为数字、字母与下划线的组合，长度为3-32个字符；不同Biztype关联不同的业务场景与识别能力策略，调用前请确认正确的Biztype
         :type BizType: str
